@@ -2,6 +2,7 @@
  *
  * Copyright (C) 2003 Klaus-Dieter Krannich <kd@k3b.org>
  * Copyright (C) 2009 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 2011 Michal Malek <michalm@jabster.pl>
  *
  * This file is part of the K3b project.
  * Copyright (C) 1998-2009 Sebastian Trueg <trueg@k3b.org>
@@ -23,12 +24,11 @@
 #include "k3bexternalbinmanager.h"
 #include "k3bglobalsettings.h"
 #include "k3bdevicehandler.h"
+#include "k3b_i18n.h"
 
-#include <KLocale>
-#include <KDebug>
-
-#include <QFile>
-#include <QTextStream>
+#include <QtCore/QDebug>
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
 
 
 
@@ -86,7 +86,7 @@ bool K3b::BinImageWritingJob::prepareWriter()
 
         // IMPROVEME: check if it's a cdrdao toc-file
         if( m_tocFile.right(4) == ".toc" ) {
-            kDebug() << "(K3b::BinImageWritingJob) imagefile has ending toc.";
+            qDebug() << "(K3b::BinImageWritingJob) imagefile has ending toc.";
             usedWritingApp = K3b::WritingAppCdrdao;
         }
         else {
@@ -97,13 +97,13 @@ bool K3b::BinImageWritingJob::prepareWriter()
             if( f.open( QIODevice::ReadOnly ) ) {
                 QTextStream fStr( &f );
                 if( fStr.readAll().contains( "MODE1/2352" ) ) {
-                    kDebug() << "(K3b::BinImageWritingJob) cuefile contains MODE1/2352 track. using cdrdao.";
+                    qDebug() << "(K3b::BinImageWritingJob) cuefile contains MODE1/2352 track. using cdrdao.";
                     usedWritingApp = K3b::WritingAppCdrdao;
                 }
                 f.close();
             }
             else
-                kDebug() << "(K3b::BinImageWritingJob) could not open file " << m_tocFile;
+                qDebug() << "(K3b::BinImageWritingJob) could not open file " << m_tocFile;
         }
     }
     else
@@ -124,28 +124,28 @@ bool K3b::BinImageWritingJob::prepareWriter()
     else {
         // create cdrdao job
         K3b::CdrdaoWriter* writer = new K3b::CdrdaoWriter( m_device, this );
-        
+
         writer->setCommand( K3b::CdrdaoWriter::WRITE );
         writer->setSimulate( m_simulate );
         writer->setBurnSpeed( m_speed );
         writer->setTocFile( m_tocFile );
         writer->setMulti( m_noFix );
-        
+
         m_writer = writer;
     }
 
-    connect( m_writer, SIGNAL(infoMessage(const QString&, int)), this, SIGNAL(infoMessage(const QString&, int)) );
+    connect( m_writer, SIGNAL(infoMessage(QString,int)), this, SIGNAL(infoMessage(QString,int)) );
     connect( m_writer, SIGNAL(percent(int)), this, SLOT(copyPercent(int)) );
     connect( m_writer, SIGNAL(subPercent(int)), this, SLOT(copySubPercent(int)) );
-    connect( m_writer, SIGNAL(processedSize(int, int)), this, SIGNAL(processedSize(int, int)) );
+    connect( m_writer, SIGNAL(processedSize(int,int)), this, SIGNAL(processedSize(int,int)) );
     connect( m_writer, SIGNAL(buffer(int)), this, SIGNAL(bufferStatus(int)) );
     connect( m_writer, SIGNAL(deviceBuffer(int)), this, SIGNAL(deviceBuffer(int)) );
-    connect( m_writer, SIGNAL(writeSpeed(int, K3b::Device::SpeedMultiplicator)), this, SIGNAL(writeSpeed(int, K3b::Device::SpeedMultiplicator)) );
+    connect( m_writer, SIGNAL(writeSpeed(int,K3b::Device::SpeedMultiplicator)), this, SIGNAL(writeSpeed(int,K3b::Device::SpeedMultiplicator)) );
     connect( m_writer, SIGNAL(finished(bool)), this, SLOT(writerFinished(bool)) );
-    connect( m_writer, SIGNAL(newTask(const QString&)), this, SIGNAL(newTask(const QString&)) );
-    connect( m_writer, SIGNAL(newSubTask(const QString&)), this, SIGNAL(newSubTask(const QString&)) );
-    connect( m_writer, SIGNAL(nextTrack(int, int)), this, SLOT(slotNextTrack(int, int)) );
-    connect( m_writer, SIGNAL(debuggingOutput(const QString&, const QString&)), this, SIGNAL(debuggingOutput(const QString&, const QString&)) );
+    connect( m_writer, SIGNAL(newTask(QString)), this, SIGNAL(newTask(QString)) );
+    connect( m_writer, SIGNAL(newSubTask(QString)), this, SIGNAL(newSubTask(QString)) );
+    connect( m_writer, SIGNAL(nextTrack(int,int)), this, SLOT(slotNextTrack(int,int)) );
+    connect( m_writer, SIGNAL(debuggingOutput(QString,QString)), this, SIGNAL(debuggingOutput(QString,QString)) );
 
     return true;
 }
@@ -185,7 +185,7 @@ void K3b::BinImageWritingJob::writerFinished(bool ok)
             if ( k3bcore->globalSettings()->ejectMedia() ) {
                 K3b::Device::eject( m_device );
             }
-            emit infoMessage( i18np("%1 copy successfully created", "%1 copies successfully created", m_copies),K3b::Job::MessageInfo );
+            emit infoMessage( i18np("One copy successfully created", "%1 copies successfully created", m_copies),K3b::Job::MessageInfo );
             jobFinished( true );
         }
         else {
@@ -216,7 +216,22 @@ QString K3b::BinImageWritingJob::jobDescription() const
 
 QString K3b::BinImageWritingJob::jobDetails() const
 {
-    return m_tocFile.section("/", -1);
+    return m_tocFile.section('/', -1);
+}
+
+
+QString K3b::BinImageWritingJob::jobSource() const
+{
+    return m_tocFile;
+}
+
+
+QString K3b::BinImageWritingJob::jobTarget() const
+{
+    if( Device::Device* device = writer() )
+        return device->vendor() + ' ' + device->description();
+    else
+        return QString();
 }
 
 
@@ -225,4 +240,4 @@ void K3b::BinImageWritingJob::setTocFile(const QString& s)
     m_tocFile = s;
 }
 
-#include "k3bbinimagewritingjob.moc"
+
