@@ -16,6 +16,9 @@
 #include <KCoreAddons/KAboutData>
 #include <KI18n/KLocalizedString>
 #include <QtCore/QCommandLineParser>
+#ifdef __clang__
+#include <sanitizer/common_interface_defs.h>
+#endif
 
 int main( int argc, char* argv[] )
 {
@@ -35,7 +38,9 @@ int main( int argc, char* argv[] )
                           QString(),
                           i18n("http://www.k3b.org" ) );
 
-    aboutData.addAuthor(i18n("Leslie Zhai"), i18n("Maintainer"), "xiangzhai83@gmail.com");
+    aboutData.setOrganizationDomain("kde");
+    aboutData.setDesktopFileName(QStringLiteral("org.kde.k3b.desktop"));
+    aboutData.addAuthor(i18n("Leslie Zhai"), i18n("Maintainer"), "lesliezhai@llvm.org.cn");
     aboutData.addAuthor(i18n("Michał Małek"),i18n("Maintainer and current lead Developer"), "michalm@jabster.pl");
     aboutData.addAuthor(i18n("Sebastian Trüg"),i18n("Main developer"), "trueg@k3b.org");
     aboutData.addAuthor(i18n("Christian Kvasny"),i18n("Video CD Project and Video CD ripping"), "chris@k3b.org");
@@ -73,8 +78,8 @@ int main( int argc, char* argv[] )
     aboutData.addCredit(i18n("Heiner Eichmann"),
                         i18n("For his work on the BSD port and some great patches."),
                         "h.eichmann@gmx.de" );
-    aboutData.addCredit(i18n("Adriaan De Groot"),
-                        i18n("For his work on the BSD port."),
+    aboutData.addCredit(i18n("Adriaan de Groot"),
+                        i18n("For his work on the FreeBSD port."),
                         "" );
     aboutData.addCredit(i18n("Thiago Macieira"),
                         i18n("For his help with the many invalid k3b entries on bugs.kde.org."),
@@ -130,5 +135,12 @@ int main( int argc, char* argv[] )
 
     app.init( parser );
 
+#ifdef __clang__
+    if (argc > 2)
+#if LLVM_MAJOR > 5
+        __sanitizer_print_memory_profile(atoi(argv[1]), atoi(argv[2]));
+#endif
+#endif
+
     return app.exec();
 }
